@@ -17,45 +17,45 @@
 #  under the License.
 
 from __future__ import unicode_literals
+
 import logging
 
 from ..transport import AsyncTransport, TransportError
-from .utils import query_params, _make_path, SKIP_IN_PATH, _bulk_body, _normalize_hosts
-
 from .async_search import AsyncSearchClient
 from .autoscaling import AutoscalingClient
 from .cat import CatClient
+from .ccr import CcrClient
 from .cluster import ClusterClient
 from .dangling_indices import DanglingIndicesClient
-from .indices import IndicesClient
-from .ingest import IngestClient
-from .nodes import NodesClient
-from .remote import RemoteClient
-from .snapshot import SnapshotClient
-from .tasks import TasksClient
-
-# xpack APIs
-from .xpack import XPackClient
-from .ccr import CcrClient
 from .data_frame import Data_FrameClient
 from .deprecation import DeprecationClient
 from .enrich import EnrichClient
 from .eql import EqlClient
+from .features import FeaturesClient
 from .graph import GraphClient
 from .ilm import IlmClient
+from .indices import IndicesClient
+from .ingest import IngestClient
 from .license import LicenseClient
+from .logstash import LogstashClient
 from .migration import MigrationClient
 from .ml import MlClient
 from .monitoring import MonitoringClient
+from .nodes import NodesClient
+from .remote import RemoteClient
 from .rollup import RollupClient
 from .searchable_snapshots import SearchableSnapshotsClient
 from .security import SecurityClient
 from .slm import SlmClient
+from .snapshot import SnapshotClient
 from .sql import SqlClient
 from .ssl import SslClient
+from .tasks import TasksClient
+from .text_structure import TextStructureClient
 from .transform import TransformClient
+from .utils import SKIP_IN_PATH, _bulk_body, _make_path, _normalize_hosts, query_params
 from .watcher import WatcherClient
-
+from .xpack import XPackClient
 
 logger = logging.getLogger("elasticsearch")
 
@@ -208,6 +208,7 @@ class AsyncElasticsearch(object):
         self.cat = CatClient(self)
         self.cluster = ClusterClient(self)
         self.dangling_indices = DanglingIndicesClient(self)
+        self.features = FeaturesClient(self)
         self.indices = IndicesClient(self)
         self.ingest = IngestClient(self)
         self.nodes = NodesClient(self)
@@ -223,8 +224,8 @@ class AsyncElasticsearch(object):
         self.eql = EqlClient(self)
         self.graph = GraphClient(self)
         self.ilm = IlmClient(self)
-        self.indices = IndicesClient(self)
         self.license = LicenseClient(self)
+        self.logstash = LogstashClient(self)
         self.migration = MigrationClient(self)
         self.ml = MlClient(self)
         self.monitoring = MonitoringClient(self)
@@ -234,6 +235,7 @@ class AsyncElasticsearch(object):
         self.slm = SlmClient(self)
         self.sql = SqlClient(self)
         self.ssl = SslClient(self)
+        self.text_structure = TextStructureClient(self)
         self.transform = TransformClient(self)
         self.watcher = WatcherClient(self)
 
@@ -267,7 +269,7 @@ class AsyncElasticsearch(object):
         """
         Returns whether the cluster is running.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/index.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/index.html>`_
         """
         try:
             return await self.transport.perform_request(
@@ -281,7 +283,7 @@ class AsyncElasticsearch(object):
         """
         Returns basic information about the cluster.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/index.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/index.html>`_
         """
         return await self.transport.perform_request(
             "GET", "/", params=params, headers=headers
@@ -301,7 +303,7 @@ class AsyncElasticsearch(object):
         Creates a new document in the index.  Returns a 409 response when a document
         with a same ID already exists in the index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/docs-index_.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-index_.html>`_
 
         :arg index: The name of the index
         :arg id: Document ID
@@ -356,7 +358,7 @@ class AsyncElasticsearch(object):
         """
         Creates or updates a document in an index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/docs-index_.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-index_.html>`_
 
         :arg index: The name of the index
         :arg body: The document
@@ -420,7 +422,7 @@ class AsyncElasticsearch(object):
         """
         Allows to perform multiple index/update/delete operations in a single request.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/docs-bulk.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-bulk.html>`_
 
         :arg body: The operation definition and data (action-data
             pairs), separated by newlines
@@ -467,7 +469,7 @@ class AsyncElasticsearch(object):
         """
         Explicitly clears the search context for a scroll.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/clear-scroll-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/clear-scroll-api.html>`_
 
         :arg body: A comma-separated list of scroll IDs to clear if none
             was specified via the scroll_id parameter
@@ -506,7 +508,7 @@ class AsyncElasticsearch(object):
         """
         Returns number of documents matching a query.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/search-count.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/search-count.html>`_
 
         :arg body: A query to restrict the results specified with the
             Query DSL (optional)
@@ -564,7 +566,7 @@ class AsyncElasticsearch(object):
         """
         Removes a document from the index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/docs-delete.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-delete.html>`_
 
         :arg index: The name of the index
         :arg id: The document ID
@@ -642,7 +644,7 @@ class AsyncElasticsearch(object):
         """
         Deletes documents matching the provided query.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/docs-delete-by-query.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-delete-by-query.html>`_
 
         :arg index: A comma-separated list of index names to search; use
             `_all` or empty string to perform the operation on all indices
@@ -739,7 +741,7 @@ class AsyncElasticsearch(object):
         Changes the number of requests per second for a particular Delete By Query
         operation.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/docs-delete-by-query.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-delete-by-query.html>`_
 
         :arg task_id: The task id to rethrottle
         :arg requests_per_second: The throttle to set on this request in
@@ -760,7 +762,7 @@ class AsyncElasticsearch(object):
         """
         Deletes a script.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/modules-scripting.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/modules-scripting.html>`_
 
         :arg id: Script ID
         :arg master_timeout: Specify timeout for connection to master
@@ -789,7 +791,7 @@ class AsyncElasticsearch(object):
         """
         Returns information about whether a document exists in an index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/docs-get.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-get.html>`_
 
         :arg index: The name of the index
         :arg id: The document ID
@@ -840,7 +842,7 @@ class AsyncElasticsearch(object):
         """
         Returns information about whether a document source exists in an index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/docs-get.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-get.html>`_
 
         :arg index: The name of the index
         :arg id: The document ID
@@ -896,7 +898,7 @@ class AsyncElasticsearch(object):
         """
         Returns information about why a specific matches (or doesn't match) a query.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/search-explain.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/search-explain.html>`_
 
         :arg index: The name of the index
         :arg id: The document ID
@@ -949,7 +951,7 @@ class AsyncElasticsearch(object):
         Returns the information about the capabilities of fields among multiple
         indices.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/search-field-caps.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/search-field-caps.html>`_
 
         :arg body: An index filter specified with the Query DSL
         :arg index: A comma-separated list of index names; use `_all` or
@@ -990,7 +992,7 @@ class AsyncElasticsearch(object):
         """
         Returns a document.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/docs-get.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-get.html>`_
 
         :arg index: The name of the index
         :arg id: The document ID
@@ -1031,7 +1033,7 @@ class AsyncElasticsearch(object):
         """
         Returns a script.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/modules-scripting.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/modules-scripting.html>`_
 
         :arg id: Script ID
         :arg master_timeout: Specify timeout for connection to master
@@ -1058,7 +1060,7 @@ class AsyncElasticsearch(object):
         """
         Returns the source of a document.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/docs-get.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-get.html>`_
 
         :arg index: The name of the index
         :arg id: The document ID
@@ -1108,7 +1110,7 @@ class AsyncElasticsearch(object):
         """
         Allows to get multiple documents in one request.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/docs-multi-get.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-multi-get.html>`_
 
         :arg body: Document identifiers; can be either `docs`
             (containing full document information) or `ids` (when index and type is
@@ -1155,7 +1157,7 @@ class AsyncElasticsearch(object):
         """
         Allows to execute several search operations in one request.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/search-multi-search.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/search-multi-search.html>`_
 
         :arg body: The request definitions (metadata-search request
             definition pairs), separated by newlines
@@ -1212,7 +1214,7 @@ class AsyncElasticsearch(object):
         """
         Allows to execute several search template operations in one request.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/search-multi-search.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/search-multi-search.html>`_
 
         :arg body: The request definitions (metadata-search request
             definition pairs), separated by newlines
@@ -1265,7 +1267,7 @@ class AsyncElasticsearch(object):
         """
         Returns multiple termvectors in one request.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/docs-multi-termvectors.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-multi-termvectors.html>`_
 
         :arg body: Define ids, documents, parameters or a list of
             parameters per document here. You must at least provide a list of
@@ -1318,7 +1320,7 @@ class AsyncElasticsearch(object):
         """
         Creates or updates a script.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/modules-scripting.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/modules-scripting.html>`_
 
         :arg id: Script ID
         :arg body: The document
@@ -1346,7 +1348,7 @@ class AsyncElasticsearch(object):
         Allows to evaluate the quality of ranked search results over a set of typical
         search queries
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/search-rank-eval.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/search-rank-eval.html>`_
 
         .. warning::
 
@@ -1395,7 +1397,7 @@ class AsyncElasticsearch(object):
         source documents by a query, changing the destination index settings, or
         fetching the documents from a remote cluster.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/docs-reindex.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-reindex.html>`_
 
         :arg body: The search definition using the Query DSL and the
             prototype for the index request.
@@ -1431,7 +1433,7 @@ class AsyncElasticsearch(object):
         """
         Changes the number of requests per second for a particular Reindex operation.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/docs-reindex.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-reindex.html>`_
 
         :arg task_id: The task id to rethrottle
         :arg requests_per_second: The throttle to set on this request in
@@ -1454,7 +1456,7 @@ class AsyncElasticsearch(object):
         """
         Allows to use the Mustache language to pre-render a search definition.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/search-template.html#_validating_templates>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/search-template.html#_validating_templates>`_
 
         :arg body: The search definition template and its params
         :arg id: The id of the stored search template
@@ -1494,7 +1496,7 @@ class AsyncElasticsearch(object):
         """
         Allows to retrieve a large numbers of results from a single search request.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/search-request-body.html#request-body-search-scroll>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/search-request-body.html#request-body-search-scroll>`_
 
         :arg body: The scroll ID if not passed by URL or query
             parameter.
@@ -1535,6 +1537,7 @@ class AsyncElasticsearch(object):
         "ignore_unavailable",
         "lenient",
         "max_concurrent_shard_requests",
+        "min_compatible_shard_node",
         "pre_filter_shard_size",
         "preference",
         "q",
@@ -1565,7 +1568,7 @@ class AsyncElasticsearch(object):
         """
         Returns results matching a query.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/search-search.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/search-search.html>`_
 
         :arg body: The search definition using the Query DSL
         :arg index: A comma-separated list of index names to search; use
@@ -1617,6 +1620,9 @@ class AsyncElasticsearch(object):
             shard requests per node this search executes concurrently. This value
             should be used to limit the impact of the search on the cluster in order
             to limit the number of concurrent shard requests  Default: 5
+        :arg min_compatible_shard_node: The minimum compatible version
+            that all shards involved in search should have for this request to be
+            successful
         :arg pre_filter_shard_size: A threshold that enforces a pre-
             filter roundtrip to prefilter search shards based on query rewriting if
             the number of shards the search request expands to exceeds the
@@ -1688,7 +1694,7 @@ class AsyncElasticsearch(object):
         Returns information about the indices and shards that a search request would be
         executed against.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/search-shards.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/search-shards.html>`_
 
         :arg index: A comma-separated list of index names to search; use
             `_all` or empty string to perform the operation on all indices
@@ -1731,7 +1737,7 @@ class AsyncElasticsearch(object):
         """
         Allows to use the Mustache language to pre-render a search definition.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/search-template.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/search-template.html>`_
 
         :arg body: The search definition template and its params
         :arg index: A comma-separated list of index names to search; use
@@ -1798,7 +1804,7 @@ class AsyncElasticsearch(object):
         Returns information and statistics about terms in the fields of a particular
         document.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/docs-termvectors.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-termvectors.html>`_
 
         :arg index: The index in which the document resides.
         :arg body: Define parameters and or supply a document to get
@@ -1857,7 +1863,7 @@ class AsyncElasticsearch(object):
         """
         Updates a document with a script or partial document.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/docs-update.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-update.html>`_
 
         :arg index: The name of the index
         :arg id: Document ID
@@ -1950,7 +1956,7 @@ class AsyncElasticsearch(object):
         Performs an update on every document in the index without changing the source,
         for example to pick up a mapping change.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/docs-update-by-query.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-update-by-query.html>`_
 
         :arg index: A comma-separated list of index names to search; use
             `_all` or empty string to perform the operation on all indices
@@ -2050,7 +2056,7 @@ class AsyncElasticsearch(object):
         Changes the number of requests per second for a particular Update By Query
         operation.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/docs-update-by-query.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-update-by-query.html>`_
 
         :arg task_id: The task id to rethrottle
         :arg requests_per_second: The throttle to set on this request in
@@ -2087,7 +2093,7 @@ class AsyncElasticsearch(object):
         """
         Returns available script types, languages and contexts
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/modules-scripting.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/modules-scripting.html>`_
 
         .. warning::
 
@@ -2103,7 +2109,7 @@ class AsyncElasticsearch(object):
         """
         Close a point in time
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/point-in-time-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/point-in-time-api.html>`_
 
         :arg body: a point-in-time id to close
         """
@@ -2118,7 +2124,7 @@ class AsyncElasticsearch(object):
         """
         Open a point in time that can be used in subsequent searches
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/point-in-time-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/point-in-time-api.html>`_
 
         :arg index: A comma-separated list of index names to open point
             in time; use `_all` or empty string to perform the operation on all
