@@ -15,7 +15,7 @@
 #  specific language governing permissions and limitations
 #  under the License.
 
-from .utils import NamespacedClient, query_params, _make_path, SKIP_IN_PATH
+from .utils import SKIP_IN_PATH, NamespacedClient, _make_path, query_params
 
 
 class IndicesClient(NamespacedClient):
@@ -25,7 +25,7 @@ class IndicesClient(NamespacedClient):
         Performs the analysis process on a text and return the tokens breakdown of the
         text.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-analyze.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-analyze.html>`_
 
         :arg body: Define analyzer/tokenizer parameters and the text on
             which the analysis should be performed
@@ -44,7 +44,7 @@ class IndicesClient(NamespacedClient):
         """
         Performs the refresh operation in one or more indices.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-refresh.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-refresh.html>`_
 
         :arg index: A comma-separated list of index names; use `_all` or
             empty string to perform the operation on all indices
@@ -72,7 +72,7 @@ class IndicesClient(NamespacedClient):
         """
         Performs the flush operation on one or more indices.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-flush.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-flush.html>`_
 
         :arg index: A comma-separated list of index names; use `_all` or
             empty string for all indices
@@ -105,7 +105,7 @@ class IndicesClient(NamespacedClient):
         """
         Creates an index with optional settings and mappings.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-create-index.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-create-index.html>`_
 
         :arg index: The name of the index
         :arg body: The configuration for the index (`settings` and
@@ -129,7 +129,7 @@ class IndicesClient(NamespacedClient):
         """
         Clones an index
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-clone-index.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-clone-index.html>`_
 
         :arg index: The name of the source index to clone
         :arg target: The name of the target index to clone into
@@ -166,7 +166,7 @@ class IndicesClient(NamespacedClient):
         """
         Returns information about one or more indices.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-get-index.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-get-index.html>`_
 
         :arg index: A comma-separated list of index names
         :arg allow_no_indices: Ignore if a wildcard expression resolves
@@ -205,7 +205,7 @@ class IndicesClient(NamespacedClient):
         """
         Opens an index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-open-close.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-open-close.html>`_
 
         :arg index: A comma separated list of indices to open
         :arg allow_no_indices: Whether to ignore if a wildcard indices
@@ -240,7 +240,7 @@ class IndicesClient(NamespacedClient):
         """
         Closes an index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-open-close.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-open-close.html>`_
 
         :arg index: A comma separated list of indices to close
         :arg allow_no_indices: Whether to ignore if a wildcard indices
@@ -254,7 +254,9 @@ class IndicesClient(NamespacedClient):
         :arg master_timeout: Specify timeout for connection to master
         :arg timeout: Explicit operation timeout
         :arg wait_for_active_shards: Sets the number of active shards to
-            wait for before the operation returns.
+            wait for before the operation returns. Set to `index-setting` to wait
+            according to the index setting `index.write.wait_for_active_shards`, or
+            `all` to wait for all shards, or an integer. Defaults to `0`.
         """
         if index in SKIP_IN_PATH:
             raise ValueError("Empty value passed for a required argument 'index'.")
@@ -274,7 +276,7 @@ class IndicesClient(NamespacedClient):
         """
         Deletes an index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-delete-index.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-delete-index.html>`_
 
         :arg index: A comma-separated list of indices to delete; use
             `_all` or `*` string to delete all indices
@@ -307,7 +309,7 @@ class IndicesClient(NamespacedClient):
         """
         Returns information about whether a particular index exists.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-exists.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-exists.html>`_
 
         :arg index: A comma-separated list of index names
         :arg allow_no_indices: Ignore if a wildcard expression resolves
@@ -337,7 +339,7 @@ class IndicesClient(NamespacedClient):
         Returns information about whether a particular document type exists.
         (DEPRECATED)
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-types-exists.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-types-exists.html>`_
 
         :arg index: A comma-separated list of index names; use `_all` to
             check the types across all indices
@@ -379,7 +381,7 @@ class IndicesClient(NamespacedClient):
         """
         Updates the index mappings.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-put-mapping.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-put-mapping.html>`_
 
         :arg body: The mapping definition
         :arg index: A comma-separated list of index names the mapping
@@ -427,7 +429,7 @@ class IndicesClient(NamespacedClient):
         """
         Returns mappings for one or more indices.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-get-mapping.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-get-mapping.html>`_
 
         :arg index: A comma-separated list of index names
         :arg doc_type: A comma-separated list of document types
@@ -466,7 +468,7 @@ class IndicesClient(NamespacedClient):
         """
         Returns mapping for one or more fields.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-get-field-mapping.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-get-field-mapping.html>`_
 
         :arg fields: A comma-separated list of fields
         :arg index: A comma-separated list of index names
@@ -501,7 +503,7 @@ class IndicesClient(NamespacedClient):
         """
         Creates or updates an alias.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-aliases.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-aliases.html>`_
 
         :arg index: A comma-separated list of index names the alias
             should point to (supports wildcards); use `_all` to perform the
@@ -529,7 +531,7 @@ class IndicesClient(NamespacedClient):
         """
         Returns information about whether a particular alias exists.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-aliases.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-aliases.html>`_
 
         :arg name: A comma-separated list of alias names to return
         :arg index: A comma-separated list of index names to filter
@@ -557,7 +559,7 @@ class IndicesClient(NamespacedClient):
         """
         Returns an alias.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-aliases.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-aliases.html>`_
 
         :arg index: A comma-separated list of index names to filter
             aliases
@@ -582,7 +584,7 @@ class IndicesClient(NamespacedClient):
         """
         Updates index aliases.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-aliases.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-aliases.html>`_
 
         :arg body: The definition of `actions` to perform
         :arg master_timeout: Specify timeout for connection to master
@@ -600,7 +602,7 @@ class IndicesClient(NamespacedClient):
         """
         Deletes an alias.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-aliases.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-aliases.html>`_
 
         :arg index: A comma-separated list of index names (supports
             wildcards); use `_all` for all indices
@@ -622,7 +624,7 @@ class IndicesClient(NamespacedClient):
         """
         Creates or updates an index template.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-templates.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-templates.html>`_
 
         :arg name: The name of the template
         :arg body: The template definition
@@ -652,7 +654,7 @@ class IndicesClient(NamespacedClient):
         """
         Returns information about whether a particular index template exists.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-templates.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-templates.html>`_
 
         :arg name: The comma separated names of the index templates
         :arg flat_settings: Return settings in flat format (default:
@@ -674,7 +676,7 @@ class IndicesClient(NamespacedClient):
         """
         Returns an index template.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-templates.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-templates.html>`_
 
         :arg name: The comma separated names of the index templates
         :arg flat_settings: Return settings in flat format (default:
@@ -695,7 +697,7 @@ class IndicesClient(NamespacedClient):
         """
         Deletes an index template.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-templates.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-templates.html>`_
 
         :arg name: The name of the template
         :arg master_timeout: Specify timeout for connection to master
@@ -721,7 +723,7 @@ class IndicesClient(NamespacedClient):
         """
         Returns settings for one or more indices.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-get-settings.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-get-settings.html>`_
 
         :arg index: A comma-separated list of index names; use `_all` or
             empty string to perform the operation on all indices
@@ -759,7 +761,7 @@ class IndicesClient(NamespacedClient):
         """
         Updates the index settings.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-update-settings.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-update-settings.html>`_
 
         :arg body: The index settings to be updated
         :arg index: A comma-separated list of index names; use `_all` or
@@ -807,7 +809,7 @@ class IndicesClient(NamespacedClient):
         """
         Provides statistics on operations happening in an index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-stats.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-stats.html>`_
 
         :arg index: A comma-separated list of index names; use `_all` or
             empty string to perform the operation on all indices
@@ -851,7 +853,7 @@ class IndicesClient(NamespacedClient):
         """
         Provides low-level information about segments in a Lucene index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-segments.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-segments.html>`_
 
         :arg index: A comma-separated list of index names; use `_all` or
             empty string to perform the operation on all indices
@@ -889,7 +891,7 @@ class IndicesClient(NamespacedClient):
         """
         Allows a user to validate a potentially expensive query without executing it.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/search-validate.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/search-validate.html>`_
 
         :arg body: The query definition specified with the Query DSL
         :arg index: A comma-separated list of index names to restrict
@@ -943,7 +945,7 @@ class IndicesClient(NamespacedClient):
         """
         Clears all or specific caches for one or more indices.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-clearcache.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-clearcache.html>`_
 
         :arg index: A comma-separated list of index name to limit the
             operation
@@ -970,7 +972,7 @@ class IndicesClient(NamespacedClient):
         """
         Returns information about ongoing index shard recoveries.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-recovery.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-recovery.html>`_
 
         :arg index: A comma-separated list of index names; use `_all` or
             empty string to perform the operation on all indices
@@ -994,7 +996,7 @@ class IndicesClient(NamespacedClient):
         """
         DEPRECATED Upgrades to the current version of Lucene.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-upgrade.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-upgrade.html>`_
 
         :arg index: A comma-separated list of index names; use `_all` or
             empty string to perform the operation on all indices
@@ -1020,7 +1022,7 @@ class IndicesClient(NamespacedClient):
         """
         DEPRECATED Returns a progress status of current upgrade.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-upgrade.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-upgrade.html>`_
 
         :arg index: A comma-separated list of index names; use `_all` or
             empty string to perform the operation on all indices
@@ -1043,7 +1045,7 @@ class IndicesClient(NamespacedClient):
         Performs a synced flush operation on one or more indices. Synced flush is
         deprecated and will be removed in 8.0. Use flush instead
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-synced-flush-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-synced-flush-api.html>`_
 
         :arg index: A comma-separated list of index names; use `_all` or
             empty string for all indices
@@ -1070,7 +1072,7 @@ class IndicesClient(NamespacedClient):
         """
         Provides store information for shard copies of indices.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-shards-stores.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-shards-stores.html>`_
 
         :arg index: A comma-separated list of index names; use `_all` or
             empty string to perform the operation on all indices
@@ -1102,7 +1104,7 @@ class IndicesClient(NamespacedClient):
         """
         Performs the force merge operation on one or more indices.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-forcemerge.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-forcemerge.html>`_
 
         :arg index: A comma-separated list of index names; use `_all` or
             empty string to perform the operation on all indices
@@ -1132,7 +1134,7 @@ class IndicesClient(NamespacedClient):
         """
         Allow to shrink an existing index into a new index with fewer primary shards.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-shrink-index.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-shrink-index.html>`_
 
         :arg index: The name of the source index to shrink
         :arg target: The name of the target index to shrink into
@@ -1165,7 +1167,7 @@ class IndicesClient(NamespacedClient):
         Allows you to split an existing index into a new index with more primary
         shards.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-split-index.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-split-index.html>`_
 
         :arg index: The name of the source index to split
         :arg target: The name of the target index to split into
@@ -1204,7 +1206,7 @@ class IndicesClient(NamespacedClient):
         Updates an alias to point to a new index when the existing index is considered
         to be too large or too old.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-rollover-index.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-rollover-index.html>`_
 
         :arg alias: The name of the alias to rollover
         :arg body: The conditions that needs to be met for executing
@@ -1245,7 +1247,7 @@ class IndicesClient(NamespacedClient):
         Freezes an index. A frozen index has almost no overhead on the cluster (except
         for maintaining its metadata in memory) and is read-only.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/freeze-index-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/freeze-index-api.html>`_
 
         :arg index: The name of the index to freeze
         :arg allow_no_indices: Whether to ignore if a wildcard indices
@@ -1281,7 +1283,7 @@ class IndicesClient(NamespacedClient):
         Unfreezes an index. When a frozen index is unfrozen, the index goes through the
         normal recovery process and becomes writeable again.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/unfreeze-index-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/unfreeze-index-api.html>`_
 
         :arg index: The name of the index to unfreeze
         :arg allow_no_indices: Whether to ignore if a wildcard indices
@@ -1309,7 +1311,7 @@ class IndicesClient(NamespacedClient):
         """
         Reloads an index's search analyzers and their resources.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-reload-analyzers.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-reload-analyzers.html>`_
 
         :arg index: A comma-separated list of index names to reload
             analyzers for
@@ -1337,7 +1339,7 @@ class IndicesClient(NamespacedClient):
         """
         Creates a data stream
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/data-streams.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/data-streams.html>`_
 
         :arg name: The name of the data stream
         """
@@ -1353,7 +1355,7 @@ class IndicesClient(NamespacedClient):
         """
         Deletes a data stream.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/data-streams.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/data-streams.html>`_
 
         :arg name: A comma-separated list of data streams to delete; use
             `*` to delete all data streams
@@ -1373,7 +1375,7 @@ class IndicesClient(NamespacedClient):
         """
         Deletes an index template.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-templates.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-templates.html>`_
 
         :arg name: The name of the template
         :arg master_timeout: Specify timeout for connection to master
@@ -1394,7 +1396,7 @@ class IndicesClient(NamespacedClient):
         """
         Returns information about whether a particular index template exists.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-templates.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-templates.html>`_
 
         :arg name: The name of the template
         :arg flat_settings: Return settings in flat format (default:
@@ -1416,7 +1418,7 @@ class IndicesClient(NamespacedClient):
         """
         Returns an index template.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-templates.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-templates.html>`_
 
         :arg name: The comma separated names of the index templates
         :arg flat_settings: Return settings in flat format (default:
@@ -1435,7 +1437,7 @@ class IndicesClient(NamespacedClient):
         """
         Creates or updates an index template.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-templates.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-templates.html>`_
 
         :arg name: The name of the template
         :arg body: The template definition
@@ -1463,7 +1465,7 @@ class IndicesClient(NamespacedClient):
         Simulate matching the given index name against the index templates in the
         system
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-templates.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-templates.html>`_
 
         :arg name: The name of the index (it must be a concrete index
             name)
@@ -1492,7 +1494,7 @@ class IndicesClient(NamespacedClient):
         """
         Returns data streams.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/data-streams.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/data-streams.html>`_
 
         :arg name: A comma-separated list of data streams to get; use
             `*` to get all data streams
@@ -1509,7 +1511,7 @@ class IndicesClient(NamespacedClient):
         """
         Simulate resolving the given template name or body
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-templates.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-templates.html>`_
 
         :arg body: New index template definition to be simulated, if no
             index template name is specified
@@ -1534,7 +1536,7 @@ class IndicesClient(NamespacedClient):
         """
         Returns information about any matching indices, aliases, and data streams
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-resolve-index-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/indices-resolve-index-api.html>`_
 
         .. warning::
 
@@ -1565,7 +1567,7 @@ class IndicesClient(NamespacedClient):
         """
         Adds a block to an index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/index-modules-blocks.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/index-modules-blocks.html>`_
 
         :arg index: A comma separated list of indices to add a block to
         :arg block: The block to add (one of read, write, read_only or
@@ -1594,7 +1596,7 @@ class IndicesClient(NamespacedClient):
         """
         Provides statistics on operations happening in a data stream.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/data-streams.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/data-streams.html>`_
 
         :arg name: A comma-separated list of data stream names; use
             `_all` or empty string to perform the operation on all data streams
@@ -1612,7 +1614,7 @@ class IndicesClient(NamespacedClient):
         Promotes a data stream from a replicated data stream managed by CCR to a
         regular data stream
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/data-streams.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/data-streams.html>`_
 
         :arg name: The name of the data stream
         """
@@ -1631,7 +1633,7 @@ class IndicesClient(NamespacedClient):
         """
         Migrates an alias to a data stream
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/data-streams.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/data-streams.html>`_
 
         :arg name: The name of the alias to migrate
         """
