@@ -15,7 +15,7 @@
 #  specific language governing permissions and limitations
 #  under the License.
 
-from .utils import NamespacedClient, query_params, _make_path, SKIP_IN_PATH, _bulk_body
+from .utils import SKIP_IN_PATH, NamespacedClient, _bulk_body, _make_path, query_params
 
 
 class MonitoringClient(NamespacedClient):
@@ -24,7 +24,7 @@ class MonitoringClient(NamespacedClient):
         """
         Used by the monitoring features to send monitoring data.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/monitor-elasticsearch-cluster.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/monitor-elasticsearch-cluster.html>`_
 
         .. warning::
 
