@@ -16,7 +16,8 @@
 #  under the License.
 
 import warnings
-from .utils import NamespacedClient, query_params, _make_path, SKIP_IN_PATH
+
+from .utils import SKIP_IN_PATH, NamespacedClient, _make_path, query_params
 
 
 class TasksClient(NamespacedClient):
@@ -33,7 +34,7 @@ class TasksClient(NamespacedClient):
         """
         Returns a list of tasks.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/tasks.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/tasks.html>`_
 
         .. warning::
 
@@ -63,7 +64,7 @@ class TasksClient(NamespacedClient):
         """
         Cancels a task, if it can be cancelled through an API.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/tasks.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/tasks.html>`_
 
         .. warning::
 
@@ -95,7 +96,7 @@ class TasksClient(NamespacedClient):
         """
         Returns information about a task.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/tasks.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/tasks.html>`_
 
         .. warning::
 
